@@ -277,7 +277,7 @@ def get_scope_of_host_ids_from_host_list():
         exit(1)
 
     sql_statement = f"SELECT t.ID, t.LAST_VM_SCANNED_DATE FROM Q_Host_List t " \
-                    f"WHERE LAST_VM_SCANNED_DATE > '{vm_processed_after}' " \
+                    f"WHERE LAST_VM_SCANNED_DATE > datetime('{vm_processed_after}') " \
                     f"ORDER BY LAST_VULN_SCAN_DATETIME DESC limit {host_list_detection_limit_hosts}"
 
     host_list_get_scope_of_host_ids_sql = sql_statement
@@ -306,7 +306,7 @@ def start_msg_get_host_list_detection_data():
 def end_msg_get_host_list_detection_data():
     etld_lib_functions.logger.info(f"host_list get_scope_of_host_ids sql: {host_list_get_scope_of_host_ids_sql}")
     etld_lib_functions.logger.info(f"host_list sqlite file: {etld_lib_config.host_list_sqlite_file}")
-    etld_lib_functions.logger.info(f"host_list host id count: {len(host_list_records):,}")
+    etld_lib_functions.logger.info(f"count host_list host id: {len(host_list_records):,}")
     etld_lib_functions.logger.info(f"end")
 
 
