@@ -351,9 +351,10 @@ def get_kb_user_config():
         kb_last_modified_after = qetl_manage_user_selected_datetime
         etld_lib_functions.logger.info(f"kb_last_modified_after set by qetl_manage_user -d option - {kb_last_modified_after}")
     elif kb_last_modified_after == 'default':
-        #  By default get last 7 days of changes.
         kb_last_modified_after = api_date.get_utc_date_minus_days(7)
-        etld_lib_functions.logger.info(f"kb_last_modified_after utc.now minus 7 days - {kb_last_modified_after}")
+        # TODO kb_last_modified_after is reset in knowledgebase_process_00_extract via function
+        # TODO setup_vars_required_for_direct_execution_of_main.  Move function here for consistency.
+        #etld_lib_functions.logger.info(f"kb_last_modified_after utc.now minus 7 days - {kb_last_modified_after}")
     else:
         etld_lib_functions.logger.info(f"kb_last_modified_after yaml - {kb_last_modified_after}")
 
@@ -426,7 +427,9 @@ def get_host_list_user_config():
             host_list_sqlite_file, "LAST_VULN_SCAN_DATETIME", "Q_Host_List")
         if max_date.startswith("20"):
             etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
-            max_date = re.sub(":..Z$", ":00Z", max_date)
+            max_date = re.sub(":..$", ":00", max_date)
+            max_date = re.sub(" ", "T",max_date)
+            max_date = re.sub("$", "Z", max_date)
             host_list_vm_processed_after = max_date
             etld_lib_functions.logger.info(f"host_list_vm_processed_after using max_date from database - {host_list_vm_processed_after}")
         else:
@@ -517,15 +520,30 @@ def get_host_list_detection_user_config():
     if qetl_manage_user_selected_datetime is not None:
         host_list_detection_vm_processed_after = qetl_manage_user_selected_datetime
         host_list_vm_processed_after = qetl_manage_user_selected_datetime
-        etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after and host_list_vm_processed_after set by qetl_manage_user -d option - "
-                             f"{host_list_detection_vm_processed_after}")
+        etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after and host_list_vm_processed_after "
+                                       f"set by qetl_manage_user -d option - "
+                                       f"{host_list_detection_vm_processed_after}")
     elif host_list_detection_vm_processed_after == 'default':
-        #  By default get last 1 days of changes.
-        host_list_detection_vm_processed_after = api_date.get_utc_date_minus_days(1)
-        host_list_vm_processed_after = host_list_detection_vm_processed_after
-        etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after and host_list_vm_processed_after utc.now minus 1 days - {host_list_detection_vm_processed_after}")
+        (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
+            host_list_sqlite_file, "LAST_VULN_SCAN_DATETIME", "Q_Host_List")
+        if max_date.startswith("20"):
+            max_date = re.sub(":..$", ":00", max_date)
+            max_date = re.sub(" ", "T", max_date)
+            max_date = re.sub("$", "Z", max_date)
+            host_list_detection_vm_processed_after = max_date
+            host_list_vm_processed_after = max_date
+            etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
+            etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after and host_list_vm_processed_after using "
+                                           f"max_date from Q_Host_List database - "
+                                           f"{host_list_detection_vm_processed_after}")
+        else:
+            host_list_detection_vm_processed_after = api_date.get_utc_date_minus_days(1)
+            host_list_vm_processed_after = host_list_detection_vm_processed_after
+            etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after and host_list_vm_processed_after "
+                                           f" using utc.now minus 1 days - {host_list_detection_vm_processed_after}")
     else:
-        etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after yaml - {host_list_detection_vm_processed_after}")
+        etld_lib_functions.logger.info(f"host_list_detection_vm_processed_after yaml - "
+                                       f"{host_list_detection_vm_processed_after}")
 
     if host_list_detection_payload_option == 'notags':
         etld_lib_functions.logger.info(f"host_list_detection_payload_option yaml - {host_list_detection_payload_option}")
